@@ -1,3 +1,5 @@
+/* jslint browser: true */
+/* global jQuery, yafowil */
 /* 
  * yafowil datepicker widget
  * 
@@ -5,25 +7,26 @@
  * Optional: bdajax
  */
 
-if (typeof(window['yafowil']) == "undefined") yafowil = {};
+if (window.yafowil === undefined) {
+    window.yafowil = {};
+}
 
-(function($) {
+(function($, yafowil) {
+    "use strict";
 
     $(document).ready(function() {
         // initial binding
         yafowil.datepicker.binder();
 
         // add after ajax binding if bdajax present
-        if (typeof(window['bdajax']) != "undefined") {
-            $.extend(bdajax.binders, {
-                datepicker_binder: yafowil.datepicker.binder
-            });
+        if (window.bdajax !== undefined) {
+            bdajax.register(yafowil.datepicker.binder, true);
         }
 
         // add binder to yafowil.widget.array hooks
-        if (typeof(window.yafowil['array']) != "undefined") {
+        if (yafowil.array !== undefined) {
             $.extend(yafowil.array.hooks.add, {
-                datepicker_binder: yafowil.datepicker.binder
+                datepicker_binder: yafowil.datepicker.array_binder
             });
         }
     });
@@ -32,26 +35,30 @@ if (typeof(window['yafowil']) == "undefined") yafowil = {};
 
         datepicker: {
 
-        	icon: '/++resource++yafowil.widget.datetime/images/cal16_16.gif',
-
             binder: function(context) {
                 $('input.datepicker', context).datepicker({
                     showAnim: null,
-                    showOn: 'both',
-                    buttonImage: yafowil.datepicker.icon,
-                    buttonImageOnly: true
+                    showOn: 'both'
                 });
                 $('input.timepicker', context).timepicker({
                     showPeriodLabels: false,
                     showOn: 'both'
                 });
+            },
+
+            array_binder: function(context) {
+                $('input.datepicker', context).removeClass('hasDatepicker');
+                $('input.timepicker', context).removeClass('hasTimepicker');
+                $('.ui-datepicker-trigger', context).remove();
+                $('.ui-timepicker-trigger', context).remove();
+                yafowil.datepicker.binder(context);
             }
         }
     });
 
     // Configure jQuery.UI datepicker languages.
     $(function() {
-        $.datepicker.regional['de'] = {
+        $.datepicker.regional.de = {
             clearText: 'löschen',
             clearStatus: 'aktuelles Datum löschen',
             closeText: 'schließen',
@@ -91,9 +98,9 @@ if (typeof(window['yafowil']) == "undefined") yafowil = {};
             initStatus: 'Wähle ein Datum',
             isRTL: false
         };
-        $.datepicker.setDefaults($.datepicker.regional['de']);
+        $.datepicker.setDefaults($.datepicker.regional.de);
 
-        $.timepicker.regional['de'] = {
+        $.timepicker.regional.de = {
             hourText: 'Stunde',
             minuteText: 'Minuten',
             amPmText: ['AM', 'PM'] ,
@@ -101,7 +108,7 @@ if (typeof(window['yafowil']) == "undefined") yafowil = {};
             nowButtonText: 'Aktuelle Zeit',
             deselectButtonText: 'Wischen'
         };
-        $.timepicker.setDefaults($.timepicker.regional['de']);
+        $.timepicker.setDefaults($.timepicker.regional.de);
     });
 
-})(jQuery);
\ No newline at end of file
+})(jQuery, yafowil);
